@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2008-2015 Jonathan Mercier-Ganady
+	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -120,13 +120,6 @@ namespace Code
         return thisObject();
     }
 
-    QScriptValue ProgressDialog::close()
-    {
-        mProgressDialog->close();
-
-        return thisObject();
-    }
-
 	int ProgressDialog::showModal()
 	{
 		return mProgressDialog->exec();
